<?php
/* (c) 2000 Ying Zhang (ying@zippydesign.com) */
/* (c) 2001 Marco Pratesi <pratesi@telug.it> */

if (!empty($errormsg)) {
	include ("$CFG->localelangdir" . "/global-error.inc.php");
	echo "<blockquote>";
	echo "<h2><div style='color: #ff0000'>" . $Errors . "</div></h2>";
	echo "<div class=\"normal\">";
	echo $errormsg;
	echo "</div>";
	echo "</blockquote>";
}

if (!empty($noticemsg)) {
	$t = new Template();
	include ("$CFG->localelangdir" . "/global-common.inc.php");
	echo "<blockquote>";
	echo "<div class=\"notice\">";
	echo $t->get_var($noticemsg);
	echo "</div>";
	echo "</blockquote>";
}

?>
